==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/admin/messages/id/base.php <==
<?php

return [
    'About' => 'Tentang',
    'Admin' => 'Admin',
    'Administration' => 'Administrasi',
    'Approval' => 'Disetujui',
    'Authentication' => 'Autentikasi',
    'Back to overview' => 'Kembali ke overview',
    'Basic' => 'Dasar',
    'Caching' => 'Caching',
    'Cronjobs' => 'Cronjobs',
    'Default' => 'Bawaan',
    'Design' => 'Desain',
    'Files' => 'Dokumen',
    'General' => 'Umum',
    'Groups' => 'Grup',
    'Logging' => 'Masuk',
    'Mailing' => 'Email',
    'Modules' => 'Modul',
    'Notifications' => 'Pemberitahuan',
    'OEmbed providers' => 'OEmbed providers',
    'Open documentation' => 'Buka dokumen',
    'Pending user registrations' => 'Pendaftaran tertunda',
    'Permissions' => 'Perizinan',
    'Proxy' => 'Proxy',
    'Self test' => 'Self test',
    'Settings' => 'Pengaturan',
    'Sign up' => 'Daftar',
    'Spaces' => 'Ruang',
    'Statistics' => 'Statistik',
    'User posts' => 'Post pengguna',
    'Userprofiles' => 'Profil pengguna',
    'Users' => 'Pengguna',
    '<strong>Administration</strong> menu' => '',
    '<strong>Maintenance</strong> Mode' => '',
    '<strong>Module </strong> administration' => '',
    '<strong>Warning</strong> incomplete setup!' => '',
    'Administrative group' => '',
    'Administrators' => '',
    'Advanced' => '',
    'Advanced settings' => '',
    'Appearance' => '',
    'Back to user overview' => '',
    'Base URL needs to begin with http:// or https://' => '',
    'Default group for administrators of this HumHub Installation' => '',
    'Default group for all newly registered users of the network' => '',
    'Delete all' => '',
    'Delete selected rows' => '',
    'Groups (Note: The Administrator group of this user can\'t be managed with your permissions)' => '',
    'Information' => '',
    'Invite' => '',
    'Invited by' => '',
    'Logs' => '',
    'OEmbed' => '',
    'People' => '',
    'The cron job for the background jobs (queue) does not seem to work properly.' => '',
    'The cron job for the regular tasks (cron) does not seem to work properly.' => '',
];

==> humhub-1.11.3.tar.gz: humhub-1.11.3/protected/humhub/modules/admin/messages/id/base.php <==
<?php

return [
    'About' => 'Tentang',
    'Admin' => 'Admin',
    'Administration' => 'Administrasi',
    'Approval' => 'Disetujui',
    'Authentication' => 'Autentikasi',
    'Back to overview' => 'Kembali ke overview',
    'Basic' => 'Dasar',
    'Caching' => 'Caching',
    'Cronjobs' => 'Cronjobs',
    'Default' => 'Bawaan',
    'Design' => 'Desain',
    'Files' => 'Dokumen',
    'General' => 'Umum',
    'Groups' => 'Grup',
    'Logging' => 'Masuk',
    'Mailing' => 'Email',
    'Modules' => 'Modul',
    'Notifications' => 'Pemberitahuan',
    'OEmbed providers' => 'OEmbed providers',
    'Open documentation' => 'Buka dokumen',
    'Pending user registrations' => 'Pendaftaran tertunda',
    'Permissions' => 'Perizinan',
    'Proxy' => 'Proxy',
    'Self test' => 'Self test',
    'Settings' => 'Pengaturan',
    'Sign up' => 'Daftar',
    'Spaces' => 'Ruang',
    'Statistics' => 'Statistik',
    'User not found!' => 'Pengguna tidak ditemukan!',
    'Userprofiles' => 'Profil pengguna',
    'Users' => 'Pengguna',
    '<strong>Administration</strong> menu' => '',
    '<strong>Maintenance</strong> Mode' => '',
    '<strong>Module</strong> Administration' => '',
    '<strong>Warning</strong> incomplete setup!' => '',
    'Activate' => '',
    'Add Licence Key' => '',
    'Administrative group' => '',
    'Administrators' => '',
    'Advanced' => '',
    'Advanced settings' => '',
    'Appearance' => '',
    'Back to user overview' => '',
    'Base URL needs to begin with http:// or https://' => '',
    'Configure' => '',
    'Deactivate' => '',
    'Default group for administrators of this HumHub Installation' => '',
    'Default group for all newly registered users of the network' => '',
    'Delete all' => '',
    'Delete selected rows' => '',
    'Groups (Note: The Administrator group of this user can\'t be managed with your permissions)' => '',
    'Information' => '',
    'Invalid user state: {state}' => '',
    'Invite' => '',
    'Invited by' => '',
    'Logs' => '',
    'No modules installed yet. Install some to enhance the functionality!' => '',
    'OEmbed' => '',
    'People' => '',
    'Search' => '',
    'Search...' => '',
    'Set as default' => '',
    'The cron job for the background jobs (queue) does not seem to work properly.' => '',
    'The cron job for the regular tasks (cron) does not seem to work properly.' => '',
    'Uninstall' => '',
];
